# frozen_string_literal: true
#
# Copyright (c) 2006-2024 Hal Brodigan (postmodern.mod3 at gmail.com)
#
# ronin-support is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# ronin-support is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with ronin-support.  If not, see <https://www.gnu.org/licenses/>.
#

require 'ronin/support/text/entropy'

class String

  #
  # Calculates the entropy for the given string.
  #
  # @param [Hash{Symbol => Object}] kwargs
  #   Additional keyword arguments.
  #
  # @option kwargs [Integer] :base (2)
  #   The base to calculate the entropy for.
  #
  # @return [Float]
  #   The entropy for the string.
  #
  # @see Ronin::Support::Text::Entropy.calculate
  #
  # @since 1.0.0
  #
  # @api public
  #
  def entropy(**kwargs)
    Ronin::Support::Text::Entropy.calculate(self,**kwargs)
  end

end
